<?php

/**
 * @package   FL Amp Plugin
 * @author    Дмитрий Васюков http://fictionlabs.ru
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

// Vars

$siteName           = $this->params->get('settings_sitename', 'My Site');
$footerText         = $this->params->get('settings_footer_text', '(c) 2018 My Site');
$favicon            = $this->params->get('settings_favicon');
$faviconApple       = $this->params->get('settings_favicon_apple');
$sidebarPos         = $this->params->get('settings_sidebar_position', 'left');
$adEnadble          = $this->params->get('ad_enable', 0);
$analiticsEnable    = $this->params->get('analitics_enable', 0);
$shareEnable        = $this->params->get('share_enable', 0);
$sharePos           = $this->params->get('share_position', 'top');
$backBtn            = $this->params->get('settings_back_btn', 1);
$fontawesomeEnable  = $this->params->get('styles_fontawesome_enable', 0);
$title              = $this->document->getTitle();
$description        = $this->document->getDescription();
$image              = $this->getImageFromText($body) ? $this->getAbsoluteUrl($this->getImageFromText($body)) : '';
$addLightbox        = $this->params->get('settings_img_links', 0);

?>
<!doctype html>
<html amp>
    <head>
        <meta charset="utf-8">
        <title><?php echo $title; ?></title>
        
        <!-- Add Favicon -->
        <?php if ($favicon) : ?>
            <link rel="icon" type="image/png" href="<?php echo JURI::root().$favicon; ?>" />
        <?php endif; ?>

        <?php if ($favicon) : ?>
            <link rel="apple-touch-icon-precomposed" type="image/png" href="<?php echo JURI::root().$faviconApple; ?>" />
        <?php endif; ?>
    
        <!-- Add Meta -->
        <meta name="viewport" content="width=device-width,minimum-scale=1,initial-scale=1">
        <meta name="description" content="<?php echo $description; ?>" />
        <meta property="og:type" content="article" />
        <meta property="og:title" content="<?php echo $title; ?>" />
        <meta property="og:description" content="<?php echo $description; ?>" />
        <meta property="og:url" content="<?php echo JURI::current(); ?>" />
        <meta property="og:site_name" content="<?php echo $siteName; ?>" />

        <?php if ($image) : ?>
            <meta property="og:image" content="<?php echo $image; ?>">
        <?php endif; ?>
        
        <!-- Add Scripts -->

        <?php if ($analiticsEnable) : ?>
            <script async custom-element="amp-analytics" src="https://cdn.ampproject.org/v0/amp-analytics-0.1.js"></script>
        <?php endif; ?>

        <script async src="https://cdn.ampproject.org/v0.js"></script>
        <script async custom-element="amp-sidebar" src="https://cdn.ampproject.org/v0/amp-sidebar-0.1.js"></script>
        <script async custom-element="amp-youtube" src="https://cdn.ampproject.org/v0/amp-youtube-0.1.js"></script>
        <script async custom-element="amp-ad" src="https://cdn.ampproject.org/v0/amp-ad-0.1.js"></script>

        <!-- Add Lightbox -->
        <?php if ($addLightbox == 1) :?>
            <script async custom-element="amp-image-lightbox" src="https://cdn.ampproject.org/v0/amp-image-lightbox-0.1.js"></script>
        <?php endif; ?>

        <!-- Add FontAwesome -->

        <?php if ($fontawesomeEnable) : ?>
            <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css">
        <?php endif; ?>

        <?php if ($shareEnable) : ?>
            <script async custom-element="amp-social-share" src="https://cdn.ampproject.org/v0/amp-social-share-0.1.js"></script>
        <?php endif; ?>
        
        <!-- Add Canonical -->
        <link rel="canonical" href="<?php echo $canonical; ?>">
        <link rel="amphtml" href="<?php echo JURI::current(); ?>?flview=amp" />
        
        <!-- Add Styles -->
        <?php include dirname(__FILE__) . '/subtmpl/styles.php'; ?>
        
        <!-- Add Microdata -->
        <?php include dirname(__FILE__) . '/subtmpl/microdata.php'; ?>

    </head>

    <body>
        <amp-sidebar id="amp-sidebar" layout="nodisplay" side="<?php echo $sidebarPos; ?>">
            <div role="button" aria-label="close sidebar" on="tap:amp-sidebar.toggle" tabindex="0" class="amp-close-btn amp-close-btn-<?php echo $sidebarPos; ?>">✕</div>
            
            <?php if($this->document->countModules('amp-menu')) : ?>
                <?php echo $this->renderModule('amp-menu'); ?>
            <?php endif;?>
        </amp-sidebar>

        <header class="amp-header flex justify-start items-center top-0 left-0 right-0 pl2 pr4 <?php echo $this->params->get('settings_fixed_header', 0) ? 'fixed' : ''; ?>">
            <div role="button" on="tap:amp-sidebar.toggle" tabindex="0" class="amp-menu-toggle align-middle inline-block mr1 caps text-decoration-none">☰</div>
            <div class="h3 center truncate caps col-12"><?php echo $siteName; ?></div>
        </header>

        <div class="amp-container">
            
            <!-- Advertisement -->
            <?php if($adEnadble) : ?>
                <div class="amp-ad amp-ad-top center">
                    <?php include dirname(__FILE__) . '/subtmpl/advertisement.php'; ?>
                </div>
            <?php endif;?>
            
            <!-- Main Top Module -->
            <?php if($this->document->countModules('amp-main-top')) : ?>
                <div class="amp-modules amp-modules-top">
                    <?php echo $this->renderModule('amp-main-top'); ?>
                </div>
            <?php endif;?>
            
            <!-- Share Buttons Before Content -->
            <?php if ($shareEnable && $sharePos == 'top') : ?>
                <div class="amp-share amp-share-top">
                    <?php include dirname(__FILE__) . '/subtmpl/share.php'; ?>
                </div>
            <?php endif;?>
            
            <!-- Body Content -->
            <?php echo $body; ?>

            <!-- Share Buttons After Content -->
            <?php if ($shareEnable && $sharePos == 'bottom') : ?>
                <div class="amp-share amp-share-bottom">
                    <?php include dirname(__FILE__) . '/subtmpl/share.php'; ?>
                </div>
            <?php endif;?>
            
            <!-- Main Bottom Module -->
            <?php if($this->document->countModules('amp-main-bottom')) : ?>
                <div class="amp-modules amp-modules-bottom">
                    <?php echo $this->renderModule('amp-main-bottom'); ?>
                </div>
            <?php endif;?>
            
            <!-- Advertisement -->
            <?php if($adEnadble) : ?>
                <div class="amp-ad amp-ad-bottom center">
                    <?php include dirname(__FILE__) . '/subtmpl/advertisement.php'; ?>
                </div>
            <?php endif;?>
        </div>

        <footer class="amp-footer flex justify-start items-center top-0 left-0 right-0 pl2 pr4">
            
            <!-- Back Button -->
            <?php if($backBtn) : ?>
                <div class="amp-footer-back-button center col-12">
                    <a href="<?php echo JURI::current().'?flview=noamp'; ?>" class="amp-btn caps">Полная версия</a>
                </div>
            <?php endif;?>

            <div class="amp-footer-bottom h4 center truncate caps col-12"><?php echo $footerText; ?></div>
        </footer>

        <!-- Analitics -->
        <?php if ($analiticsEnable) : ?>
            <?php include dirname(__FILE__) . '/subtmpl/analitics.php'; ?>
        <?php endif; ?>
        
        <!-- Lightbox -->
        <?php if ($addLightbox == 1) :?>
            <amp-image-lightbox id="amp_lightbox" layout="nodisplay"></amp-image-lightbox>
        <?php endif; ?>
        
    </body>
</html>